@@ -24,7 +24,7 @@ Copyright_License {
 #include "BasicComputer.hpp"
 #include "NMEA/MoreData.hpp"
 #include "NMEA/Derived.hpp"
-#include "ComputerSettings.hpp"
+#include "Settings.hpp"
 #include "Atmosphere/AirDensity.hpp"
 
 #define fixed_inv_g fixed(1.0/9.81)
@@ -436,12 +436,9 @@ BasicComputer::Compute(MoreData &data,
     ComputeGroundSpeed(data, last_gps);
     ComputeAirspeed(data, calculated);
   }
-#ifndef NDEBUG
-  // For testing without gps.
-  // When CPU load is low enough it can be done for every sample.
-  else if (data.dyn_pressure_available)
+  else if ((data.dyn_pressure_available) ||
+           (data.pitot_pressure_available && data.static_pressure_available))
     ComputeAirspeed(data, calculated);
-#endif
 
   ComputeHeading(data.attitude, data, calculated);
 
